Answering Causal Questions
===========================

In the following sub-sections, we'll dive deep into all causal questions the GCM-based inference in
DoWhy can answer and explain the concepts behind them and how to interpret the results.


.. toctree::
    :maxdepth: 1

    quantify_arrow_strength
    quantify_intrinsic_causal_influence
    simulate_impact_of_interventions
    computing_counterfactuals
    average_causal_effect
    attribute_distributional_changes
